@@ -1,10 +1,10 @@
-Index: geos/source/index/bintree/Root.cpp
+Index: geos/src/index/bintree/Root.cpp
 ===================================================================
---- geos.orig/source/index/bintree/Root.cpp	2011-05-25 13:02:47.000000000 +0200
-+++ geos/source/index/bintree/Root.cpp	2011-05-25 13:03:44.000000000 +0200
-@@ -20,11 +20,14 @@
- #include <geos/index/quadtree/IntervalSize.h>
+--- geos.orig/src/index/bintree/Root.cpp	2011-11-30 16:54:52.000000000 +0100
++++ geos/src/index/bintree/Root.cpp	2011-12-02 14:36:34.000000000 +0100
+@@ -21,11 +21,14 @@
  
+ #include <cstddef>
  #include <cassert>
 +#include <cstddef>
  
@@ -17,10 +17,10 @@ Index: geos/source/index/bintree/Root.cpp
  double Root::origin=0.0;
  
  void
-Index: geos/source/index/quadtree/Root.cpp
+Index: geos/src/index/quadtree/Root.cpp
 ===================================================================
---- geos.orig/source/index/quadtree/Root.cpp	2011-05-25 13:02:47.000000000 +0200
-+++ geos/source/index/quadtree/Root.cpp	2011-05-25 13:03:17.000000000 +0200
+--- geos.orig/src/index/quadtree/Root.cpp	2011-11-30 16:54:52.000000000 +0100
++++ geos/src/index/quadtree/Root.cpp	2011-12-02 14:36:34.000000000 +0100
 @@ -25,6 +25,7 @@
  #include <geos/geom/Envelope.h>
  
